@@ -82,6 +82,7 @@ void Zone::printStatistics( const char * comment ) const {
              << " :: >      lines:  " << setw(5) << _lines.length << endl
              << " :: >      sects:  " << setw(5) << _sectors.length << endl
              << " :: > sect specs:  " << setw(5) << _sectSpecials.length << endl
+             << " :: >    scripts:  " << setw(5) << _scripts.length << endl
              << " :: >   textures:  " << setw(5) << _texnames.length << endl
              << " :: >     lights:  " << setw(5) << _lights.length << endl;
 
@@ -128,13 +129,13 @@ void Zone::printStatistics( const char * comment ) const {
                         max_vis = max( _sectors[i]->_visibleSectors.size(), max_vis );
                         total_vis += _sectors[i]->_visibleSectors.size();
 
-                        max_visfloors = max( _sectors[i]->_visibleFloors.size(), max_vis );
+                        max_visfloors = max( _sectors[i]->_visibleFloors.size(), max_visfloors );
                         total_visfloors += _sectors[i]->_visibleFloors.size();
 
-                        max_visceilings = max( _sectors[i]->_visibleCeilings.size(), max_vis );
+                        max_visceilings = max( _sectors[i]->_visibleCeilings.size(), max_visceilings );
                         total_visceilings += _sectors[i]->_visibleCeilings.size();
 
-                        max_vislines = max( _sectors[i]->_visibleLines.size(), max_vis );
+                        max_vislines = max( _sectors[i]->_visibleLines.size(), max_vislines );
                         total_vislines += _sectors[i]->_visibleLines.size();
                         
                         bool first_time = true;
@@ -192,7 +193,7 @@ void Zone::printStatistics( const char * comment ) const {
                 total_vis         /= _sectors.length;
                 total_visfloors   /= _sectors.length;
                 total_visceilings /= _sectors.length;
-                total_vislines    /= _sectors.length;
+                total_vislines    /= _lines.length;
 
                 avg_texmatch_all_floors /= _sectors.length;
                 
